//
//  Villo.h
//  villo
//
//  Created by Philip Bernstein on 4/10/12.
//  Copyright (c) 2012 __MyCompanyName__. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "VilloRequest.h"
#import "CEPubnub.h"
@class Villo;
typedef void (^VilloCompletionHandler)(VilloRequest *connection, NSError *error, NSString *urlString, NSData *data);

@protocol VilloChatDelgate
@optional
-(void)messageReceived:(NSString *)message username:(NSString *)username room:(NSString *)room extra:(NSMutableDictionary *)extra;
@end
@protocol VilloRequestDelegate
@optional
-(void)loginCompletedWithResponse:(BOOL)success;
-(void)friendAddedWithResponse:(BOOL)success username:(NSString *)username;
-(void)friendsReceivedWithResponse:(NSDictionary *)friends error:(BOOL)error;
-(void)friendRemovedWithResponse:(BOOL)response username:(NSString *)username;
-(void)leadersReceivedWithResponse:(NSDictionary *)leaders error:(BOOL)error;
@end
@interface Villo : NSObject <CEPubnubDelegate>
{
    CEPubnub *pubnub;
    bool isAuthenticated;
    VilloRequest *loginRequest;
    VilloRequest *friendRequest;
    VilloRequest *leaderRequest;
}
-(id)initWithOptions:(NSMutableDictionary *)options chat:(BOOL)chat;

// leader board related methods
-(void)getLeaders:(NSString *)duration board:(NSString *)board limit:(int)limit;
// friends related methods
-(void)addFriend:(NSString *)user;
-(void)getFriends;
-(void)removeFriend:(NSString *)user;

// chat related methods
-(void)subscribe:(NSString *)room;
-(BOOL)isSubscribed:(NSString *)room;
-(void)publish:(NSString *)message room:(NSString *)room extra:(NSDictionary *)extra;


// various login / startup calls
-(void)login:(NSString *)user password:(NSString *)password;

/* utility to send authenticated request to API endpoint, for use in the future when new features are
    added to the web API, but not yet implemented in the library */
-(void)sendRequestToURL:(NSString *)urlString method:(NSString *)method parameters:(NSMutableDictionary *)parameters callback:(VilloCompletionHandler)handler;

@property (nonatomic, retain) id ChatDelegate;
@property (nonatomic, retain) id RequestDelegate;

@property (nonatomic, retain) NSString *username;
@property (nonatomic, retain) NSString *apiKey;
@property (nonatomic, retain) NSString *appId;
@property (nonatomic, retain) NSString *token;
@end
